@@ -1,6 +1,6 @@
 import re
 import sys
-from alembic.testing import TestBase, exclusions
+from alembic.testing import TestBase, exclusions, assert_raises
 
 from alembic.operations import ops
 from sqlalchemy import MetaData, Column, Table, String, \
@@ -13,7 +13,7 @@ from sqlalchemy.types import TIMESTAMP
 from sqlalchemy.types import UserDefinedType
 from sqlalchemy.dialects import mysql, postgresql
 from sqlalchemy.engine.default import DefaultDialect
-from sqlalchemy.sql import and_, column, literal_column, false
+from sqlalchemy.sql import and_, column, literal_column, false, table
 from alembic.migration import MigrationContext
 from alembic.autogenerate import api
 
@@ -154,7 +154,7 @@ class AutogenRenderTest(TestBase):
                 autogenerate.render_op_text(autogen_context, op_obj),
                 """op.create_index('foo_idx', 't', \
 ['x', 'y'], unique=False, """
-                """postgresql_where=sa.text(!U"t.y = 'something'"))"""
+                """postgresql_where=sa.text(!U"y = 'something'"))"""
             )
         else:
             eq_ignore_whitespace(
@@ -178,7 +178,7 @@ unique=False, """
         eq_ignore_whitespace(
             autogenerate.render_op_text(self.autogen_context, op_obj),
             "op.create_index('test_lower_code_idx', 'test', "
-            "[sa.text(!U'lower(test.code)')], unique=False)"
+            "[sa.text(!U'lower(code)')], unique=False)"
         )
 
     @config.requirements.fail_before_sqla_080
@@ -210,7 +210,7 @@ unique=False, """
         eq_ignore_whitespace(
             autogenerate.render_op_text(self.autogen_context, op_obj),
             "op.create_index('test_desc_code_idx', 'test', "
-            "[sa.text(!U'test.code DESC')], unique=False)"
+            "[sa.text(!U'code DESC')], unique=False)"
         )
 
     def test_drop_index(self):
@@ -1458,6 +1458,21 @@ unique=False, """
             "existing_server_default=sa.text(!U'5'))"
         )
 
+    def test_render_executesql_plaintext(self):
+        op_obj = ops.ExecuteSQLOp("drop table foo")
+        eq_(
+            autogenerate.render_op_text(self.autogen_context, op_obj),
+            "op.execute('drop table foo')"
+        )
+
+    def test_render_executesql_sqlexpr_notimplemented(self):
+        sql = table('x', column('q')).insert()
+        op_obj = ops.ExecuteSQLOp(sql)
+        assert_raises(
+            NotImplementedError,
+            autogenerate.render_op_text, self.autogen_context, op_obj
+        )
+
 
 class RenderNamingConventionTest(TestBase):
     __requires__ = ('sqlalchemy_094',)
